==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/en-ID/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Konfirmasi hapus semua aset',
  'bulk_delete_help'	=> 'Tinjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset ini dapat dipulihkan, namun tidak akan dikaitkan lagi dengan pengguna yang saat ini mereka tentukan.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count assets.',
	'bulk_update'		=> 'Perbarui Aset secara massal',
	'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa aset sekaligus. Hanya mengisi kolom yang Anda butuhkan untuk mengubah. Setiap bidang dibiarkan kosong tidak berubah. ',
	'bulk_update_warn'	=> 'Anda akan mengedit properti :asset_count aset.',
    'checkedout_to'		=> 'Checkout ke',
    'checkout_date'		=> 'Tanggal Check out',
    'checkin_date'		=> 'Tanggal Check in',
    'checkout_to'		=> 'Checkout ke',
    'cost'				=> 'Biaya pembelian',
    'create'			=> 'Buat Aset',
    'date'				=> 'Tanggal Pemebelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan pada',
    'default_location'	=> 'Lokasi Standar',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Nilai EOL',
    'expected_checkin'  => 'Tanggal Checkin yang Diharapkan',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Sepenuhnya disusutkan',
    'help_checkout'		=> 'Jika Anda ingin segera menetapkan aset ini, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pabrikan',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Permintaan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui aset',
    'warranty'			=> 'Garansi',
		'warranty_expires'		=> 'Garansi kadaluarsa',
    'years'				=> 'tahun',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/en-ID/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Konfirmasi hapus semua aset',
  'bulk_delete_help'	=> 'Tinjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset ini dapat dipulihkan, namun tidak akan dikaitkan lagi dengan pengguna yang saat ini mereka tentukan.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count assets.',
    'bulk_update'		=> 'Perbarui Aset secara massal',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa aset sekaligus. Hanya mengisi kolom yang Anda butuhkan untuk mengubah. Setiap bidang dibiarkan kosong tidak berubah. ',
    'bulk_update_warn'	=> 'Anda akan mengedit properti :asset_count aset.',
    'checkedout_to'		=> 'Checkout ke',
    'checkout_date'		=> 'Tanggal Check out',
    'checkin_date'		=> 'Tanggal Check in',
    'checkout_to'		=> 'Checkout ke',
    'cost'				=> 'Biaya pembelian',
    'create'			=> 'Buat Aset',
    'date'				=> 'Tanggal Pemebelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan pada',
    'default_location'	=> 'Lokasi Standar',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Nilai EOL',
    'expected_checkin'  => 'Tanggal Checkin yang Diharapkan',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Sepenuhnya disusutkan',
    'help_checkout'		=> 'Jika Anda ingin segera menetapkan aset ini, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pabrikan',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Permintaan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui aset',
    'warranty'			=> 'Garansi',
        'warranty_expires'		=> 'Garansi kadaluarsa',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
